@@ -316,7 +316,7 @@ class CalcDataFrame(object):
 
     @staticmethod
     def get_period_max_retracement(data: pd.DataFrame, period: [str, list], interval_insufficient: bool = True,
-                                   method: str = 'MF',
+                                   method: str = 'MF', offset: int = -1,
                                    start_date: datetime.datetime = datetime.datetime(year=1990, month=1, day=1),
                                    end_date: datetime.datetime = datetime.datetime.today(),
                                    suffix: str = '_max_retracement', swanav_column: str = 'swanav'):
@@ -335,6 +335,9 @@ class CalcDataFrame(object):
             MF-最高净值回落法
             MD-最大跌幅法
 
+        offset:
+            偏移量
+
         start_date:
             计算开始日期
 
@@ -357,7 +360,7 @@ class CalcDataFrame(object):
             for per in period:
                 temp = cal_data.apply(func=CalcDataFrame.get_row_max_retracement,
                                       args=(
-                                          data, per, interval_insufficient, method, suffix,
+                                          data, per, interval_insufficient, method, offset, suffix,
                                           swanav_column),
                                       axis=1)
                 result = temp if len(result) == 0 else pd.merge(result, temp, how='left', left_index=True,
@@ -366,7 +369,7 @@ class CalcDataFrame(object):
 
     @staticmethod
     def get_row_max_retracement(row, data: pd.DataFrame, period: str, interval_insufficient: bool = True,
-                                method: str = 'MF',
+                                method: str = 'MF', offset: int = -1,
                                 suffix: str = '_max_retracement', swanav_column: str = 'swanav'):
         """
         获取某一日期（一行数据）的最大回撤
@@ -395,14 +398,15 @@ class CalcDataFrame(object):
         """
         result = pd.Series(dtype=float)
         curr_date = row.name
-        real_date = calc_date(curr_date, period, data.index[0])
+        curr_idx, per_date = CalcDataFrame.get_loc(data.index, curr_date, period=period, method='ffill', offset=offset)
+        real_date = data.index[curr_idx]
 
         max_retracement = np.nan
         edate = pd.NaT
         bdate = pd.NaT
         rdate = pd.NaT
         rdays = np.nan
-        if real_date >= data.index[0] or not interval_insufficient:
+        if per_date >= data.index[0] or interval_insufficient:
             per_data = data[real_date:curr_date]
             if method == 'MF':
                 # 从高净值跌到低净值
@@ -602,7 +606,7 @@ class CalcDataFrame(object):
 
     @staticmethod
     def get_period_beta(fund_ret: pd.DataFrame, market_ret: pd.DataFrame, period: [str, list],
-                        interval_insufficient: bool = True,
+                        interval_insufficient: bool = True, offset: int = -1,
                         start_date: datetime.datetime = datetime.datetime(year=1990, month=1, day=1),
                         end_date: datetime.datetime = datetime.datetime.today(),
                         fund_colunm: str = 'fund_ret',
@@ -656,7 +660,9 @@ class CalcDataFrame(object):
         if isinstance(period, list):
             for per in period:
                 temp = cal_data.apply(CalcDataFrame.get_row_beta,
-                                      args=(all_data, per, interval_insufficient, fund_colunm, market_colunm, suffix),
+                                      args=(
+                                          all_data, per, interval_insufficient, offset, fund_colunm, market_colunm,
+                                          suffix),
                                       axis=1)
                 result = temp if len(result) == 0 else pd.merge(result, temp, how='left', left_index=True,
                                                                 right_index=True)
@@ -665,14 +671,17 @@ class CalcDataFrame(object):
         return result
 
     @staticmethod
-    def get_row_beta(row, all_data: pd.DataFrame, period, interval_insufficient, fund_colunm, market_colunm, suffix):
+    def get_row_beta(row, all_data: pd.DataFrame, period, interval_insufficient, offset, fund_colunm, market_colunm,
+                     suffix):
         result = pd.Series(dtype=float)
         curr_date = row.name
-        real_date = calc_date(curr_date, period, all_data.index[0])
-        if real_date < all_data.index[0] or not interval_insufficient:
+        curr_idx, real_date = CalcDataFrame.get_loc(all_data.index, curr_date, period=period, method='ffill',
+                                                    offset=offset)
+        pre_date = all_data.index[curr_idx]
+        if real_date < all_data.index[0] and not interval_insufficient:
             result[period + suffix] = pd.NA
         else:
-            real_data = all_data[real_date:curr_date]
+            real_data = all_data[pre_date:curr_date]
             result[period + suffix] = real_data[fund_colunm].cov(real_data[market_colunm]) / np.var(
                 real_data[market_colunm])
         return result
